diff --git a/src/java/com/threerings/miso/tile/TileUtil.java b/src/java/com/threerings/miso/tile/TileUtil.java
index 89d6b25df..11a6fddb8 100644
--- a/src/java/com/threerings/miso/tile/TileUtil.java
+++ b/src/java/com/threerings/miso/tile/TileUtil.java
@@ -1,5 +1,5 @@
//
-// $Id: TileUtil.java,v 1.3 2001/08/16 23:14:21 mdb Exp $
+// $Id: TileUtil.java,v 1.4 2001/09/05 00:44:37 shaper Exp $
package com.threerings.miso.tile;
@@ -17,18 +17,18 @@ import com.threerings.miso.scene.AmbulatorySprite;
public class TileUtil
{
/**
* Returns an array of multi-frame images corresponding to the frames
* of animation used to render the mobile sprite in each of the
* directions it may face. The tileset id referenced must contain
* Path.NUM_DIRECTIONS rows of tiles, with each row
* containing NUM_DIR_FRAMES tiles.
*
* @param tilemgr the tile manager to retrieve tiles from.
* @param tsid the tileset id containing the sprite tiles.
*
* @return the array of multi-frame sprite images.
*/
- public static MultiFrameImage[] getSpriteFrames (
+ public static MultiFrameImage[] getAmbulatorySpriteFrames (
TileManager tilemgr, int tsid)
{
MultiFrameImage[] anims = new MultiFrameImage[Path.NUM_DIRECTIONS];
@@ -17,18 +17,18 @@ import com.threerings.miso.scene.AmbulatorySprite;
{
/**
- * Returns an array of multi-frame images corresponding to the frames
- * of animation used to render the mobile sprite in each of the
- * directions it may face. The tileset id referenced must contain
- * Path.NUM_DIRECTIONS rows of tiles, with each row
- * containing NUM_DIR_FRAMES tiles.
+ * Returns an array of multi-frame images corresponding to the
+ * frames of animation used to render the ambulatory sprite in
+ * each of the directions it may face. The tileset id referenced
+ * must contain Path.NUM_DIRECTIONS rows of tiles,
+ * with each row containing NUM_DIR_FRAMES tiles.
*
* @param tilemgr the tile manager to retrieve tiles from.